@@ -11,8 +11,7 @@ import torch
 from typing import Union
 from tqdm import tqdm
 from ailca.core.env import *
-from ailca.data.base import Data
-from ailca.data.base import Dataset
+from ailca.data.base import Data, Dataset
 
 
 def load_dataset(path_data_file: str,
