@@ -9,20 +9,17 @@ It provides abstracted frames to implement the prediction models.
 from __future__ import annotations
 import joblib
 import torch
-from abc import ABC
-from abc import abstractmethod
+from abc import ABC, abstractmethod
 from typing import Union
 from copy import deepcopy
-from sklearn.linear_model import LinearRegression
-from sklearn.linear_model import Lasso
+from sklearn.linear_model import LinearRegression, Lasso
 from sklearn.tree import DecisionTreeRegressor
 from gplearn.genetic import SymbolicRegressor
 from sklearn.kernel_ridge import KernelRidge
 from sklearn.neighbors import KNeighborsRegressor
 from sklearn.svm import SVR
 from sklearn.gaussian_process import GaussianProcessRegressor
-from sklearn.gaussian_process.kernels import DotProduct
-from sklearn.gaussian_process.kernels import WhiteKernel
+from sklearn.gaussian_process.kernels import DotProduct, WhiteKernel
 from xgboost import XGBRegressor
 from torch.utils.data import DataLoader
 from ailca.core.env import *
