@@ -2,8 +2,7 @@ import torch
 import torch.nn.functional as F
 import torchvision.models.resnet as resnet
 import torchvision.models.densenet as densenet
-from abc import ABCMeta
-from abc import abstractmethod
+from abc import ABCMeta, abstractmethod
 from typing import Union
 from torch.utils.data import DataLoader
 from ailca.core.env import *
