@@ -160,7 +160,21 @@ def k_fold_cross_validation(k_folds: list,
                             init_lr: float = 1e-3,
                             l2_reg: float = 1e-6,
                             n_epochs: int = 300,
-                            random_seed: int = 0):
+                            random_seed: int = 0) -> dict:
+    """
+
+    :param k_folds:
+    :param model:
+    :param batch_size:
+    :param gradient_method:
+    :param loss_func:
+    :param init_lr:
+    :param l2_reg:
+    :param n_epochs:
+    :param random_seed:
+    :return: (*dict*) A dictionary
+    """
+
     scores = list()
     idx_test = list()
     preds = list()
@@ -225,7 +239,7 @@ def load_exp_info(path_exp_file: str) -> dict:
 
 
 def load_model(model_info: Union[str, dict],
-               path_model_file: str) -> Model:
+               path_model_file: str = None) -> Model:
     if isinstance(model_info, str):
         with open(model_info, 'r') as f:
             _model_info = json.loads(f.read())
@@ -238,7 +252,10 @@ def load_model(model_info: Union[str, dict],
     else:
         model = __config_model(_model_info)
 
-    model.load(path_model_file)
+    if path_model_file is None:
+        model.load(_model_info['path_model_file'])
+    else:
+        model.load(path_model_file)
 
     return model
 
